@@ -175,69 +175,69 @@
 
 /***ja
     @addtogroup m17nFont
-    @brief եȥ֥.
+    @brief フォントオブジェクト.
 
-    m17n GUI API ϥեȤ @c MFont Υ֥ȤȤɽ롣
-    եȤ @e եȥץѥƥ ĤȤǤ롣¾ΥפΥ
-    ѥƥƱ͡եȥץѥƥϥͤʤꡢϰʲΥ
-    ܥΤ줫Ǥ롣
+    m17n GUI API はフォントを @c MFont 型のオブジェクトとして表現する。
+    フォントは @e フォントプロパティ を持つことができる。他のタイプのプ
+    ロパティ同様、フォントプロパティはキーと値からなり、キーは以下のシ
+    ンボルのいずれかである。
 
     @c Mfoundry, @c Mfamily, @c Mweight, @c Mstyle, @c Mstretch,
     @c Madstyle, @c Mregistry, @c Msize, @c Mresolution, @c Mspacing
 
-    եȥץѥƥΥ @c Msize 뤤 @c Mresolution 
-    ξ硢ͤͤǤꡢʳξ硢ͤϥܥǤ롣
+    フォントプロパティのキーが @c Msize あるいは @c Mresolution 
+    の場合、値は整数値であり、キーがそれ以外の場合、値はシンボルである。
 
-    ֥ե F ΥեȥץѥƥΤ @c Mxxx 
-    ǤΡפΤȤñˡF  xxx ץѥƥפȸƤ֤Ȥ롣
+    「フォント F のフォントプロパティのうちキーが @c Mxxx 
+    であるもの」のことを簡単に「F の xxx プロパティ」と呼ぶことがある。
 
-    foundry ץѥƥͤϡadobe, misc 
-    ΥեȤγȯ򼨤ܥǤ롣
+    foundry プロパティの値は、adobe, misc 
+    等のフォントの開発元情報を示すシンボルである。
 
-    family ץѥƥͤϡtimes, helvetica 
-    Υեȥեߥ꡼򼨤ܥǤ롣
+    family プロパティの値は、times, helvetica 
+    等のフォントファミリーを示すシンボルである。
 
-    weight ץѥƥͤϡnormal, bold ˴ؤ򼨤ܥǤ롣
+    weight プロパティの値は、normal, bold 等の太さに関する情報を示すシンボルである。
 
-    style ץѥƥͤϡnormal, italic 
-    Υ˴ؤ򼨤ܥǤ롣
+    style プロパティの値は、normal, italic 
+    等のスタイルに関する情報を示すシンボルである。
 
-    stretch ץѥƥͤϡnormal, semicondensed 
-    ʸ˴ؤ򼨤ܥǤ롣
+    stretch プロパティの値は、normal, semicondensed 
+    等の文字幅に関する情報を示すシンボルである。
 
-    adstyle ץѥƥͤϡserif, sans-serif
-    Ūʥեȥեߥ꡼˴ؤ򼨤ܥǤ롣
+    adstyle プロパティの値は、serif, sans-serif
+    等の抽象的なフォントファミリーに関する情報を示すシンボルである。
 
-    registry ץѥƥͤϡiso10646, iso8895-1
-    Υ쥸ȥ򼨤ܥǤ롣
+    registry プロパティの値は、iso10646, iso8895-1
+    等のレジストリ情報を示すシンボルである。
 
-    size ץѥƥͤϡեȤΥǥ󥵥ɽ魯ͤǤꡢ
-    ñ̤1/10 ݥȤǤ롣
+    size プロパティの値は、フォントのデザインサイズを表わす整数値であり、
+    単位は1/10 ポイントである。
 
-    resolution ץѥƥͤϡꤵƤǥХβ٤ɽ魯
-    ͤǤꡢñ̤dots per inch (dpi) Ǥ롣
+    resolution プロパティの値は、想定されているデバイスの解像度を表わす
+    整数値であり、単位はdots per inch (dpi) である。
 
-    type ץѥƥͤϡեȥɥ饤Фؼ Mx ⤷
-    Mfreetype Ǥ롣
+    type プロパティの値は、フォントドライバを指示し、現在 Mx もしくは
+    Mfreetype である。
 
-    m17n 饤֥ϥեȥ֥Ȥ򣲤ĤŪѤƤ롣
-    ꥱץफեȤλŪȡץꥱ
-    ץѲǽʥեȤ󼨤ŪǤ롣ץꥱ
-    ץФ󼨤ԤݤˤϡեȥץѥƥϤ
-    ƶŪͤġ
+    m17n ライブラリはフォントオブジェクトを２つの目的で用いている。アプ
+    リケーションプログラムからフォントの指定を受け取る目的と、アプリケー
+    ションプログラムに利用可能なフォントを提示する目的である。アプリケー
+    ションプログラムに対して提示を行う際には、フォントプロパティはすべ
+    て具体的な値を持つ。
 
-    m17n 饤֥ Window ƥեȡFreeTypeեȡ
-    OpenTypeեȤΣ򥵥ݡȤƤ롣
+    m17n ライブラリは Window システムフォント、FreeTypeフォント、
+    OpenTypeフォントの３種類をサポートしている。
 
     <ul>
 
-    <li> Window ƥե
+    <li> Window システムフォント
 
-    m17n X 饤֥ϡX Ф X եȥФ갷ƤΥեȤ򥵥ݡȤ롣
-    XLFD γƥեɤȥեȥץѥƥбϰʲ̤ꡣɽˤʤեɤ̵뤵롣
+    m17n X ライブラリは、X サーバと X フォントサーバが取り扱う全てのフォントをサポートする。
+    XLFD の各フィールドとフォントプロパティの対応は以下の通り。この表にないフィールドは無視される。
 
 @verbatim
-    XLFD ե                             ץѥƥ
+    XLFD フィールド                             プロパティ
     ---------------                             --------
     FOUNDRY                                     foundry
     FAMILY_NAME                                 family
@@ -252,20 +252,20 @@
 
     <li> FreeType fonts
 
-    m17n 饤֥ϡFreeType 饤֥Ȥ褦ꤵ줿ˤϡ
-    FreeType ٤ƤΥեȤ򥵥ݡȤ롣ѿ 
-    #mfont_freetype_path  m17n 饤֥ȴĶѿ @c M17NDIR 
-    ˱ƽ롣ܺ٤ѿ򻲾ȤΤȡ
+    m17n ライブラリは、FreeType ライブラリを使うように設定された場合には、
+    FreeType が扱うすべてのフォントをサポートする。変数 
+    #mfont_freetype_path は m17n ライブラリの設定と環境変数 @c M17NDIR 
+    に応じて初期化される。詳細は変数の説明を参照のこと。
 
-    ⤷ m17n 饤֥꤬ fontconfig 饤֥Ȥ褦ꤵ줿ˤϡ
-    #mfont_freetype_path ˲äơ fontconfig ǻѲǽʥեȤ⤹٤ƥݡȤ롣
+    もし m17n ライブラリが fontconfig ライブラリを使うように設定された場合には、
+    #mfont_freetype_path に加えて、 fontconfig で使用可能なフォントもすべてサポートされる。
 
-    FreeType եȤΥեߥ̾ family ץѥƥб롣
-    FreeType եȤΥ̾ϡɽΤ褦 weight, style,
-    stretch ץѥƥб롣
+    FreeType フォントのファミリ名は family プロパティに対応する。
+    FreeType フォントのスタイル名は、下の表のように weight, style,
+    stretch プロパティに対応する。
 
 @verbatim
-    ̾          weight  style   stretch
+    スタイル名          weight  style   stretch
     ----------          ------  -----   -------
     Regular             medium  r       normal
     Italic              medium  i       normal
@@ -281,15 +281,15 @@
     BoldOblique         bold    o       normal
 @endverbatim
 
-    ɽ˸ʤ̾ "Regular" Ȥư롣
+    上の表に現われないスタイル名は "Regular" として扱われる。
 
-    platform ID  encoding ID Ȥ߹碌 registry 
-    ץѥƥб롣ȤФեȤ (1 1) Ȥ ID ȹ礻ƤС
-    registry ץѥƥ 1-1 Ȥʤ롣ˤˤȹ礻ˤϰʲΤ褦Ѥ
-    registry ץѥƥ ͿƤ롣
+    platform ID と encoding ID の組み合わせが registry 
+    プロパティに対応する。たとえばあるフォントが (1 1) という ID の組合せを持てば、
+    registry プロパティは 1-1 となる。頻繁にあらわれる組合せには以下のような定義済み
+    registry プロパティ が与えられている。
 
 @verbatim
-    platform ID         encoding ID     registry ץѥƥ
+    platform ID         encoding ID     registry プロパティ
     -----------         -----------     -----------------
     0                   3               unicode-bmp
     0                   4               unicode-full
@@ -298,20 +298,20 @@
     3                   1               unicode-full
 @endverbatim
 
-    äơĤȹ礻 (1 0) (3 1) ĥեȤϡ줾
-    registry ץѥƥ 1-0, apple-roman, 3-1, unicode-bmp
-    Ǥ룴ĤΥեȥ֥Ȥб롣
+    したがって、二つの組合せ (1 0) 、(3 1) を持つフォントは、それぞれ
+    registry プロパティが 1-0, apple-roman, 3-1, unicode-bmp
+    である４つのフォントオブジェクトに対応する。
 
-    <li> OpenType ե
+    <li> OpenType フォント
 
-    m17n 饤֥ϡFreeType 饤֥ OTF 
-    饤֥Ѥ褦ꤹС٤Ƥ OpenType 
-    եȤ򥵥ݡȤ롣ºݤѤǤեȤΥꥹȤ FreeType
-    եȤξƱͤ˺롣OpenType եȤ FLT (Font Layout Table)
-    ͳǻѤ褦եȥåȤ˻ꤵƤꡢFLT  OTF 
-    ϢΥޥ (Ȥ otf:deva) СOTF 饤֥꤬եȤ OpenType
-    쥤ȥơ֥˽äʸ򥰥եѴFreeType
-    饤֥꤬ƥդΥӥåȥޥåץ᡼󶡤롣
+    m17n ライブラリは、FreeType ライブラリと OTF 
+    ライブラリを使用するように設定すれば、すべての OpenType 
+    フォントをサポートする。実際に利用できるフォントのリストは FreeType
+    フォントの場合と同様に作られる。OpenType フォントを FLT (Font Layout Table)
+    経由で使用するようフォントセットに指定されており、FLT に OTF 
+    関連のコマンド (たとえば otf:deva) があれば、OTF ライブラリがフォントの OpenType
+    レイアウトテーブルに従って文字列をグリフコード列に変換し、FreeType
+    ライブラリが各グリフのビットマップイメージを提供する。
 
     </ul>
 
@@ -1947,7 +1947,7 @@ mfont__check_capability (MRealizedFont *rfont, MSymbol capability)
 /*=*/
 
 /***en @name Variables: Keys of font property.  */
-/***ja @name ѿ: եȥץѥƥꤹѤߥܥ */
+/***ja @name 変数: フォントプロパティを指定する定義済みシンボル */
 /*** @{ */
 /*=*/
 
@@ -1958,11 +1958,11 @@ mfont__check_capability (MRealizedFont *rfont, MSymbol capability)
     is used as a key of font property and face property.  The property
     value must be a symbol whose name is a foundry name of a font.  */
 /***ja
-    @brief ȯꤹեȥץѥƥΥ.
+    @brief 開発元を指定するフォントプロパティのキー.
     
-    ѿ #Mfoundry  <tt>"foundry"</tt> 
-    Ȥ̾ĥܥǤꡢեȥץѥƥȥեץѥƥΥȤѤ롣
-    ͤϡեȤγȯ̾̾ȤƻĥܥǤ롣    */
+    変数 #Mfoundry は <tt>"foundry"</tt> 
+    という名前を持つシンボルであり、フォントプロパティとフェースプロパティのキーとして用いられる。
+    値は、フォントの開発元名を名前として持つシンボルである。    */
 
 MSymbol Mfoundry;
 
@@ -1973,11 +1973,11 @@ MSymbol Mfoundry;
     used as a key of font property and face property.  The property
     value must be a symbol whose name is a family name of a font.  */ 
 /***ja
-    @brief եߥꤹեȥץѥƥΥ.
+    @brief ファミリを指定するフォントプロパティのキー.
     
-    ѿ #Mfamily  <tt>"family"</tt> 
-    Ȥ̾ĥܥǤꡢեȥץѥƥȥեץѥƥΥȤѤ롣
-    ͤϡեȤΥեߥ̾̾ȤƻĥܥǤ롣    */
+    変数 #Mfamily は <tt>"family"</tt> 
+    という名前を持つシンボルであり、フォントプロパティとフェースプロパティのキーとして用いられる。
+    値は、フォントのファミリ名を名前として持つシンボルである。    */
 
 MSymbol Mfamily;
 
@@ -1989,11 +1989,11 @@ MSymbol Mfamily;
     value must be a symbol whose name is a weight name of a font (e.g
     "medium", "bold").  */ 
 /***ja
-    @brief ꤹեȥץѥƥΥ.
+    @brief 太さを指定するフォントプロパティのキー.
     
-    ѿ #Mweight  <tt>"weight"</tt> 
-    Ȥ̾ĥܥǤꡢեȥץѥƥȥեץѥƥΥȤѤ롣
-    ͤϡեȤ̾ ( "medium", "bold" ) ̾ȤƻĥܥǤ롣    */
+    変数 #Mweight は <tt>"weight"</tt> 
+    という名前を持つシンボルであり、フォントプロパティとフェースプロパティのキーとして用いられる。
+    値は、フォントの太さ名 ( "medium", "bold" 等) を名前として持つシンボルである。    */
 
 MSymbol Mweight;
 
@@ -2005,11 +2005,11 @@ MSymbol Mweight;
     value must be a symbol whose name is a style name of a font (e.g
     "r", "i", "o").  */ 
 /***ja
-    @brief ꤹեȥץѥƥΥ.
+    @brief スタイルを指定するフォントプロパティのキー.
     
-    ѿ #Mstyle  <tt>"style"</tt> 
-    Ȥ̾ĥܥǤꡢեȥץѥƥȥեץѥƥΥȤѤ롣
-    ͤϡեȤΥ̾ ("r", "i", "o" )̾ȤƻĥܥǤ롣    */
+    変数 #Mstyle は <tt>"style"</tt> 
+    という名前を持つシンボルであり、フォントプロパティとフェースプロパティのキーとして用いられる。
+    値は、フォントのスタイル名 ("r", "i", "o" 等)を名前として持つシンボルである。    */
 
 MSymbol Mstyle;
 
@@ -2021,11 +2021,11 @@ MSymbol Mstyle;
     value must be a symbol whose name is a stretch name of a font (e.g
     "normal", "condensed").  */ 
 /***ja
-    @brief ꤹեȥץѥƥΥ.
+    @brief 幅を指定するフォントプロパティのキー.
     
-    ѿ #Mstretch  <tt>"stretch"</tt> 
-    Ȥ̾ĥܥǤꡢեȥץѥƥȥեץѥƥΥȤѤ롣
-    ͤϡեȤʸ̾ ( "normal", "condensed" )̾ȤƻĥܥǤ롣    */
+    変数 #Mstretch は <tt>"stretch"</tt> 
+    という名前を持つシンボルであり、フォントプロパティとフェースプロパティのキーとして用いられる。
+    値は、フォントの文字幅名 ( "normal", "condensed" 等)を名前として持つシンボルである。    */
 
 MSymbol Mstretch;
 
@@ -2037,11 +2037,11 @@ MSymbol Mstretch;
     value must be a symbol whose name is an additional style name of a
     font (e.g "serif", "", "sans").  */ 
 /***ja
-    @brief adstyle ꤹեȥץѥƥΥ.
+    @brief adstyle を指定するフォントプロパティのキー.
     
-    ѿ #Madstyle  <tt>"adstyle"</tt> 
-    Ȥ̾ĥܥǤꡢեȥץѥƥȥեץѥƥΥȤѤ롣
-    ͤϡեȤ adstyle ̾("serif", "", "sans" )̾ȤƻĥܥǤ롣    */
+    変数 #Madstyle は <tt>"adstyle"</tt> 
+    という名前を持つシンボルであり、フォントプロパティとフェースプロパティのキーとして用いられる。
+    値は、フォントの adstyle 名("serif", "", "sans" 等)を名前として持つシンボルである。    */
 
 MSymbol Madstyle;
 
@@ -2053,11 +2053,11 @@ MSymbol Madstyle;
     symbol whose name specifies the spacing of a font (e.g "p" for
     proportional, "m" for monospaced).  */ 
 /***ja
-    @brief spacing ꤹեȥץѥƥΥ.
+    @brief spacing を指定するフォントプロパティのキー.
     
-    ѿ #Mspacing  <tt>"spacing"</tt> Ȥ̾ĥܥǤꡢ
-    եȥץѥƥΥȤѤ롣ͤϡեȤ spacing
-    򼨤̾ ("p", "m" )ĥܥǤ롣  */
+    変数 #Mspacing は <tt>"spacing"</tt> という名前を持つシンボルであり、
+    フォントプロパティのキーとして用いられる。値は、フォントの spacing
+    特性を示す名前 ("p", "m" 等)を持つシンボルである。  */
 
 MSymbol Mspacing;
 
@@ -2069,12 +2069,12 @@ MSymbol Mspacing;
     a symbol whose name is a registry name a font registry
     (e.g. "iso8859-1", "jisx0208.1983-0").  */ 
 /***ja
-    @brief 쥸ȥꤹեȥץѥƥΥ.
+    @brief レジストリを指定するフォントプロパティのキー.
     
-    ѿ #Mregistry  <tt>"registry"</tt> 
-    Ȥ̾ĥܥǤꡢեȥץѥƥȥեץѥƥΥȤѤ롣
-    ͤϡեȤΥ쥸ȥ̾ ( "iso8859-1", "jisx0208.1983-0" 
-    ) ̾ȤƻĥܥǤ롣    */
+    変数 #Mregistry は <tt>"registry"</tt> 
+    という名前を持つシンボルであり、フォントプロパティとフェースプロパティのキーとして用いられる。
+    値は、フォントのレジストリ名 ( "iso8859-1", "jisx0208.1983-0" 
+    等) を名前として持つシンボルである。    */
 
 MSymbol Mregistry;
 
@@ -2086,12 +2086,12 @@ MSymbol Mregistry;
     value must be an integer specifying a font design size in the unit
     of 1/10 point (on 100 dpi display).  */ 
 /***ja
-    @brief ꤹեȥץѥƥΥ.
+    @brief サイズを指定するフォントプロパティのキー.
     
-    ѿ #Msize  <tt>"size"</tt> 
-    Ȥ̾ĥܥǤꡢեȥץѥƥȥեץѥƥΥȤѤ롣ͤϡ
-    100 dpi Υǥץ쥤ǤΥեȤΥǥ󥵥 1/10 
-    ݥñ̤ǼͤǤ롣
+    変数 #Msize は <tt>"size"</tt> 
+    という名前を持つシンボルであり、フォントプロパティとフェースプロパティのキーとして用いられる。値は、
+    100 dpi のディスプレイ上でのフォントのデザインサイズを 1/10 
+    ポイント単位で示す整数値である。
     */
 
 MSymbol Msize;
@@ -2111,11 +2111,11 @@ MSymbol Motf;
     and is used as a key of font property.  The property value must be
     a symbol whose name is a font file name.  */ 
 /***ja
-    @brief եȥեꤹեȥץѥƥΥ.
+    @brief フォントファイルを指定するフォントプロパティのキー.
     
-    ѿ #Mfontfile  <tt>"fontfile"</tt> Ȥ̾ĥܥǤ
-    ꡢեȥץѥƥΥȤѤ롣ͤϡեȥե
-    ̾̾ȤƻĤȤ륷ܥǤ롣 */
+    変数 #Mfontfile は <tt>"fontfile"</tt> という名前を持つシンボルであ
+    り、フォントプロパティのキーとして用いられる。値は、フォントファイ
+    ル名を名前として持つとするシンボルである。 */
 
 MSymbol Mfontfile;
 
@@ -2127,11 +2127,11 @@ MSymbol Mfontfile;
     value must be an integer to specifying a font resolution in the
     unit of dots per inch (dpi).  */ 
 /***ja
-    @brief ٤ꤹեȥץѥƥΥ.
+    @brief 解像度を指定するフォントプロパティのキー.
     
-    ѿ #Mresolution  <tt>"resolution"</tt> 
-    Ȥ̾ĥܥǤꡢեȥץѥƥȥեץѥƥΥȤѤ롣
-    ͤϡեȤβ٤ dots per inch (dpi) ñ̤ǼͤǤ롣    */
+    変数 #Mresolution は <tt>"resolution"</tt> 
+    という名前を持つシンボルであり、フォントプロパティとフェースプロパティのキーとして用いられる。
+    値は、フォントの解像度を dots per inch (dpi) 単位で示す整数値である。    */
 
 MSymbol Mresolution;
 
@@ -2152,10 +2152,10 @@ MSymbol Mmax_advance;
     The variable #Mfontconfig is to be used as an argument of the
     functions mfont_parse_name () and mfont_unparse_name ().  */
 /***ja
-    @brief "fontconfig" Ȥ̾ĥܥ.
+    @brief "fontconfig" という名前を持つシンボル.
 
-    ѿ #Mfontconfig ϴؿ mfont_parse_name ()  mfont_unparse_name ()
-    ΰȤѤ롣  */
+    変数 #Mfontconfig は関数 mfont_parse_name () と mfont_unparse_name ()
+    の引数として用いられる。  */
 
 MSymbol Mfontconfig;
 
@@ -2166,10 +2166,10 @@ MSymbol Mfontconfig;
     structure #MDrawGlyph to specify the type of \<fontp\> member is
     actually (XFontStruct *).  */
 /***ja
-    @brief "x" Ȥ̾ĥܥ.
+    @brief "x" という名前を持つシンボル.
 
-    ѿ #Mx Ϲ¤ #MDrawGlyph Υ \<type\> 
-    ͤȤѤ졢 \<fontp\> ηºݤˤ (XFontStruct *) Ǥ뤳Ȥɽ.  */
+    変数 #Mx は構造 #MDrawGlyph のメンバ \<type\> 
+    の値として用いられ、メンバ \<fontp\> の型が実際には (XFontStruct *) であることを表す.  */
 
 MSymbol Mx;
 
@@ -2180,10 +2180,10 @@ MSymbol Mx;
     of the structure #MDrawGlyph to specify the type of \<fontp\> member
     is actually FT_Face.  */
 /***ja
-    @brief "freetype" Ȥ̾ĥܥ.
+    @brief "freetype" という名前を持つシンボル.
 
-    ѿ #Mfreetype Ϲ¤ #MDrawGlyph Υ \<type\> 
-    ͤȤѤ졢 \<fontp\> ηºݤˤ FT_Face Ǥ뤳Ȥɽ  */
+    変数 #Mfreetype は構造 #MDrawGlyph のメンバ \<type\> 
+    の値として用いられ、メンバ \<fontp\> の型が実際には FT_Face であることを表す。  */
 
 MSymbol Mfreetype;
 
@@ -2194,10 +2194,10 @@ MSymbol Mfreetype;
     structure #MDrawGlyph to specify the type of \<fontp\> member
     is actually (XftFont *).  */
 /***ja
-    @brief  "xft" Ȥ̾ĥܥ.
+    @brief  "xft" という名前を持つシンボル.
 
-    ѿ #Mxft Ϲ¤ #MDrawGlyph Υ \<type\> 
-    ͤȤѤ졢 \<fontp\> ηºݤˤ (XftFont *) Ǥ뤳Ȥɽ  */
+    変数 #Mxft は構造 #MDrawGlyph のメンバ \<type\> 
+    の値として用いられ、メンバ \<fontp\> の型が実際には (XftFont *) であることを表す。  */
 
 MSymbol Mxft;
 
@@ -2224,20 +2224,20 @@ MSymbol Mxft;
     If the m17n library is not configured to use the FreeType library,
     this variable is not used.  */
 /***ja
-    @brief եȥեȥեȥեޤǥ쥯ȥΥꥹ.
+    @brief フォントファイルとフォントファイルを含むディレクトリのリスト.
 
-    ѿ @c mfont_freetype_path ϡեȥեȥեȥեޤǥ쥯ȥ 
-    plist Ǥ롣ǤΥ @c Mstring 
-    Ǥꡢͤϥեȥե뤫ǥ쥯ȥ򼨤ʸǤ롣
+    変数 @c mfont_freetype_path は、フォントファイルとフォントファイルを含むディレクトリの 
+    plist である。各要素のキーは @c Mstring 
+    であり、値はフォントファイルかディレクトリを示す文字列である。
 
-    ޥ M17N_INIT () ˤäơѿ m17n ǡ١ȴĶѿ 
-    "M17NDIR" Υ֥ǥ쥯ȥ "fonts" ޤ褦ꤵ롣
-    mframe () κǽθƤӽФκݤˡѿºݤ˻ѤǤեȤꥹȤ롣
-    ǥץꥱץϡmframe () 
-    ƤˡɬפʤСˤѿѹʤƤϤʤʤ
-    Ǥɲäˤϡͤϰ˳ǤʸǤʤƤϤʤʤ
+    マクロ M17N_INIT () によって、この変数は m17n データベースと環境変数 
+    "M17NDIR" 双方のサブディレクトリ "fonts" を含むように設定される。
+    mframe () の最初の呼び出しの際に、この変数から実際に使用できるフォントの内部リストが作られる。
+    そこでアプリケーションプログラムは、mframe () 
+    を呼ぶ前に（必要ならば）この変数を変更しなくてはならない。
+    新しい要素を追加する場合には、その値は安全に開放できる文字列でなくてはならない。
 
-    m17n 饤֥꤬ FreeType 饤֥Ȥ褦ꤵƤʤˤϡѿѤʤ */
+    m17n ライブラリが FreeType ライブラリを使うように設定されてない場合には、この変数は用いられない。 */
 
 MPlist *mfont_freetype_path;
 
@@ -2252,12 +2252,12 @@ MPlist *mfont_freetype_path;
     @return
     This function returns a pointer to the created font object.  */
 /***ja
-    @brief եȤ.
+    @brief 新しいフォントを作る.
 
-    ؿ mfont () ϥץѥƥڻʤեȤ򥪥֥Ȥ롣
+    関数 mfont () はプロパティを一切持たない新しいフォントをオブジェクトを作る。
 
     @return
-    δؿϺäեȥ֥ȤؤΥݥ󥿤֤  */
+    この関数は作ったフォントオブジェクトへのポインタを返す。  */
 
 MFont *
 mfont ()
@@ -2288,20 +2288,20 @@ mfont ()
     to the created font.  Otherwise it returns @c NULL.  */
 
 /***ja
-    @brief ե̾եȤ.
+    @brief フォント名からフォントを作る.
 
-    ؿ mfont_parse_name () ϡե̾ 
-    $NAME Ф줿ץѥƥġեȥ֥Ȥ롣
+    関数 mfont_parse_name () は、フォント名 
+    $NAME から取り出されたプロパティを持つ、新しいフォントオブジェクトを作る。
 
-    $FORMAT  $NAME ΥեޥåȤꤹ롣$FORMAT  #Mx ǤС
-    $NAME  XLFD (X Logical Font Description) ˽äƲϤ롣
-    $FORMAT  #Mfontconfig Ǥ $NAME  Fontfonfig 
-    Υեȥƥɽ˽äƲϤ롣$FORMAT  #Mnil ǤСޤ XLFD 
-    ˽äƲϤ졢˼Ԥ Fontconfig ˽äƲϤ롣
+    $FORMAT は $NAME のフォーマットを指定する。$FORMAT が #Mx であれば、
+    $NAME は XLFD (X Logical Font Description) に従って解析される。
+    $FORMAT が #Mfontconfig であれば $NAME は Fontfonfig 
+    のフォントテキスト表現に従って解析される。$FORMAT が #Mnil であれば、まず XLFD 
+    に従って解析され、それに失敗したら Fontconfig に従って解析される。
 
     @return
-     mfont_parse_name () 
-    Ͽ줿եȤؤΥݥ󥿤֤Ǥʤ @c NULL ֤  */
+    処理が成功すれば mfont_parse_name () 
+    は新しく作られたフォントへのポインタを返す。そうでなければ @c NULL を返す。  */
 
 MFont *
 mfont_parse_name (const char *name, MSymbol format)
@@ -2334,18 +2334,18 @@ mfont_parse_name (const char *name, MSymbol format)
     not freed unless the user explicitly does so by free ().  */
 
 /***ja
-    @brief եȤե̾.
+    @brief フォントからフォント名を作る.
 
-    ؿ mfont_unparse_name ()  ե̾ʸե $FONT 
-    򸵤$FORMAT ˽äƺ롣
+    関数 mfont_unparse_name () は フォント名の文字列をフォント $FONT 
+    を元に$FORMAT に従って作る。
 
-    $FORMAT  #Mx ޤ #Mfontconfig Ǥ롣
-    #Mx ʤХե̾ XLFD (X Logical Font Description) ˽
-    #Mfontconfig ʤХե̾ Fontconfig Υեȥƥɽ˽
+    $FORMAT は #Mx または #Mfontconfig である。
+    #Mx ならばフォント名は XLFD (X Logical Font Description) に従う。
+    #Mfontconfig ならばフォント名は Fontconfig のフォントテキスト表現に従う。
 
     @return 
-    δؿϿ˥Ȥե̾ʸ֤ʸϡ桼
-    free () ˤäŪ˲ʤ¤ʤ  */
+    この関数は新たにアロケートしたフォント名の文字列を返す。文字列は、ユーザが
+    free () によって明示的に解放しない限り解放されない。  */
 
 char *
 mfont_unparse_name (MFont *font, MSymbol format)
@@ -2371,9 +2371,9 @@ mfont_unparse_name (MFont *font, MSymbol format)
 
     The mfont_copy () function returns a new copy of font $FONT.  */
 /***ja
-    @brief եȤΥԡ.
+    @brief フォントのコピーを作る.
 
-    ؿ Mfont_copy () ϥե $FONT Υԡꡢ֤ */
+    関数 Mfont_copy () はフォント $FONT のコピーを作り、それを返す。 */
 
 MFont *
 mfont_copy (MFont *font)
@@ -2413,23 +2413,23 @@ mfont_copy (MFont *font)
     code to the external variable #merror_code.  */
  
 /***ja
-    @brief եȤΥץѥƥͤ.
+    @brief フォントのプロパティの値を得る.
 
-    ؿ mfont_get_prop () ϥե $FONT ΥץѥƥΤ
-    $KEY ǤΤ֤ͤ$KEY ϰʲΥܥΤ줫Ǥʤ
-    Фʤʤ
+    関数 mfont_get_prop () はフォント $FONT のプロパティのうち、キーが
+    $KEY であるものの値を返す。$KEY は以下のシンボルのいずれかでなけれ
+    ばならない。
 
 	@c Mfoundry, @c Mfamily, @c Mweight, @c Mstyle, @c Mstretch,
 	@c Madstyle, @c Mregistry, @c Msize, @c Mresolution, @c Mspacing.
 
     @return 
-    $KEY  @c Mfoundry, @c Mfamily, @c Mweight, @c Mstyle, @c
-    Mstretch, @c Madstyle, @c Mregistry, @c Mspacing Τ줫ǤС
-    ͤ򥷥ܥȤ֤եȤΥץѥƥʤ
-    ˤ@c Mnil ֤$KEY  @c Msize 뤤 @c Mresolution 
-    ˤϡͤͤȤ֤եȤΥץѥƥ
-    ʤˤ 0 ֤$KEY ʳΤΤǤС@c
-    NULL ֤ѿ #merror_code ˥顼ɤꤹ롣  */
+    $KEY が @c Mfoundry, @c Mfamily, @c Mweight, @c Mstyle, @c
+    Mstretch, @c Madstyle, @c Mregistry, @c Mspacing のいずれかであれば、
+    相当する値をシンボルとして返す。フォントがそのプロパティを持たない
+    場合には@c Mnil を返す。$KEY が @c Msize あるいは @c Mresolution の
+    場合には、相当する値をは整数値として返す。フォントがそのプロパティ
+    を持たない場合には 0 を返す。$KEY がそれ以外のものであれば、@c
+    NULL を返し、外部変数 #merror_code にエラーコードを設定する。  */
 
 void *
 mfont_get_prop (MFont *font, MSymbol key)
@@ -2512,18 +2512,18 @@ mfont_get_prop (MFont *font, MSymbol key)
     if the name is "nil", a symbol of name "Nil" must be
     specified.  */
  /***ja
-    @brief եȤΥץѥƥͤꤹ.
+    @brief フォントのプロパティに値を設定する.
 
-    ؿ mfont_put_prop () ϡե $FONT Υ$KEY Ǥץ
-    ƥͤ $VAL ꤹ롣$KEY ϰʲΥܥΤ줫Ǥ롣
+    関数 mfont_put_prop () は、フォント $FONT のキーが$KEY であるプロパ
+    ティの値を $VAL に設定する。$KEY は以下のシンボルのいずれかである。
 
 	@c Mfoundry, @c Mfamily, @c Mweight, @c Mstyle, @c Mstretch,
 	@c Madstyle, @c Mregistry, @c Msize, @c Mresolution.
 
-    $KEY  @c Msize  @c Mresolution Ǥ $VAL ͤǤʤƤ
-    ʤʳξ硢$VAL ϥץѥƥͤ̾ΥܥǤʤ
-    Ϥʤʤ⤷̾ "nil" ξϡ̾ "Nil" Υ
-    ܥǤʤƤϤʤʤ*/
+    $KEY が @c Msize か @c Mresolution であれば $VAL は整数値でなくては
+    らない。それ以外の場合、$VAL はプロパティ値の名前のシンボルでなくて
+    はならない。ただしもしその名前が "nil" の場合は、名前が "Nil" のシ
+    ンボルでなくてはならない。*/
 
 int
 mfont_put_prop (MFont *font, MSymbol key, void *val)
@@ -2583,16 +2583,16 @@ mfont_put_prop (MFont *font, MSymbol key, void *val)
    property of lower priority is preferred to a font that has a
    different value for a property of higher priority.  */
 /***ja
-    @brief եͥ٤֤.
+    @brief フォント選択の優先度を返す.
 
-    ؿ mfont_selection_priority ()  6 ĤΥܥ뤫ʤä֤
-    ǤϡʲΥեȥץѥƥΥͥٽ¤٤ΤǤ롣
+    関数 mfont_selection_priority () は 6 つのシンボルからなる配列を作って返す。
+    配列の要素は、以下のフォントプロパティのキーを優先度順に並べたものである。
 
 	@c Mfamily, @c Mweight, @c Mstyle, @c Mstretch,
 	@c Madstyle, @c Msize.
 
-   m17n 饤֥Ϥ˽äơǤפեȤ򤹤롣
-   ŪΥեȤȡ줾㤦ץѥƥͤפʤեȤä硢ͥ٤㤤ץѥƥͤפʤեȡͥ٤ι⤤ץѥƥͤפƤեȡˤ򤵤롣
+   m17n ライブラリはこの配列に従って、最も合致するフォントを選択する。
+   目的のフォントと、それぞれ違うプロパティの値が合致しないフォントがあった場合、優先度の低いプロパティの値が合致しないフォント（優先度の高いプロパティの値が合致しているフォント）が選択される。
 
    */
 
@@ -2641,16 +2641,16 @@ mfont_selection_priority ()
     See the documentation of the function mfont_selection_priority ()
     for details.  */
 /***ja
-    @brief եͥ٤ꤹ.
+    @brief フォント選択優先度を設定する.
 
-    ؿ mfont_set_selection_priority () ϡ6ĤΥܥ $KEYS 
-    ˤäƥեͥ٤ꤹ롣ϰʲγǤŬ
-    ʽ֤¤٤ΤǤ롣
+    関数 mfont_set_selection_priority () は、6つのシンボルの配列 $KEYS 
+    にしたがってフォント選択優先度を設定する。配列は以下の各要素を適切
+    な順番で並べたものである。
 
 	@c Mfamily, @c Mweight, @c Mstyle, @c Mstretch,
 	@c Madstyle, @c Msize.
 
-    ܺ٤ϴؿ mfont_selection_priority () 򻲾ȤΤȡ
+    詳細は関数 mfont_selection_priority () の説明を参照のこと。
      */
 
 int
@@ -2717,14 +2717,14 @@ mfont_set_selection_priority (MSymbol *keys)
     value that indicates how well the found font matches to $SPEC.  The
     smaller score means a better match.  */
 /***ja
-    @brief եȤõ.
+    @brief フォントを探す.
 
-    ؿ mfont_find () ϡե졼 $FRAME ǥե $SPEC 
-    ˤäȤפѲǽʥեȤؤΥݥ󥿤֤  
+    関数 mfont_find () は、フレーム $FRAME 上でフォント定義 $SPEC 
+    にもっとも合致する利用可能なフォントへのポインタを返す。  
 
-    $SCORE  NULL Ǥ뤫ĤäեȤ $SPEC 
-    ˤɤۤɹäƤ뤫򼨤¸ؤΥݥ󥿤Ǥ롣
-    ۤɤäƤ뤳Ȥ̣롣
+    $SCORE は NULL であるか、見つかったフォントが $SPEC 
+    にどれほど合っているかを示すスコアを保存する場所へのポインタである。
+    スコアが小さいほど良く合っていることを意味する。
     */
 
 MFont *
@@ -2787,18 +2787,18 @@ mfont_find (MFrame *frame, MFont *spec, int *score, int max_size)
     Otherwise it returns -1 and assigns an error code to the external
     variable #merror_code.  */
 /***ja
-    @brief եȤΥ󥳡ǥ󥰤ꤹ.
+    @brief フォントのエンコーディングを設定する.
 
-    ؿ mfont_set_encoding () ϥե $FONT Υ󥳡ǥ󥰾ꤹ롣
+    関数 mfont_set_encoding () はフォント $FONT のエンコーディング情報を設定する。
 
-    $ENCODING_NAME ϥեȤƱ󥳡ǥ󥰤ʸåȤ򼨤ܥǤ롣
+    $ENCODING_NAME はフォントと同じエンコーディングを持つ文字セットを示すシンボルである。
 
-    $REPERTORY_NAME  @c Mnil Ǥ뤫եȤƱ󥳡ǥ󥰤ʸåȤ򼨤ܥǤ롣
-    @c Mnil ǤСġʸΥեȤǥݡȤƤ뤫ɤϡơΥեȥɥ饤Ф䤤碌롣
+    $REPERTORY_NAME は @c Mnil であるか、フォントと同じエンコーディングを持つ文字セットを示すシンボルである。
+    @c Mnil であれば、個々の文字がそのフォントでサポートされているかどうかは、各々のフォントドライバに問い合わせる。
 
     @return
-    Фδؿ 0 ֤Ǥʤ -1 ֤ѿ
-    #merror_code ˥顼ɤꤹ롣  */
+    処理が成功すればこの関数は 0 を返す。そうでなければ -1 を返し、外部変数
+    #merror_code にエラーコードを設定する。  */
 
 
 int
@@ -2850,9 +2850,9 @@ mfont_set_encoding (MFont *font, MSymbol encoding_name, MSymbol repertory_name)
 
     This function is obsolete.   Use mfont_unparse_name instead. */
 /***ja
-    @brief ե̾եȤ.
+    @brief フォント名からフォントを作る.
 
-    δؿѻͽǤ롣 mfont_unparse_name () ѤΤȡ */
+    この関数は廃止予定である。 mfont_unparse_name () を使用のこと。 */
 
 char *
 mfont_name (MFont *font)
@@ -2868,9 +2868,9 @@ mfont_name (MFont *font)
     This function is obsolete.  Use mfont_parse_name () instead.  */
 
 /***ja
-    @brief եȤե̾.
+    @brief フォントからフォント名を作る.
 
-    ϴؿѻͽǤ롣 mfont_parse_name () ѤΤȡ  */
+    これは関数は廃止予定である。 mfont_parse_name () を使用のこと。  */
 
 MFont *
 mfont_from_name (const char *name)
@@ -2890,12 +2890,12 @@ mfont_from_name (const char *name)
     size.  */
 
 /***ja
-    @brief եȤΥꥵ
+    @brief フォントのリサイズ情報を得る
 
-    ؿ mfont_resize_ratio  m17n ǡ١ \<font, reisize\> 
-    򸡺ե FONT ΥꥵΨʥѡơ
-    ֤Ȥ֤ͤ 150 ǤСm17n 饤֥ϻꤵ줿 1.5 
-    ܤΥեȤѤ뤳Ȥ̣롣 */
+    関数 mfont_resize_ratio は m17n データベース \<font, reisize\> 
+    を検索し、フォント FONT のリサイズの比率（パーセンテージ）
+    を返す。たとえば返す値が 150 であれば、m17n ライブラリは指定されたサイズの 1.5 
+    倍のフォントを使用することを意味する。 */
 
 int
 mfont_resize_ratio (MFont *font)
@@ -2947,23 +2947,23 @@ mfont_resize_ratio (MFont *font)
     NULL.  */
 
 /***ja
-    @brief եȤΥꥹȤ
+    @brief フォントのリストを得る
 
-    ؿ mfont_list () ϥե졼 $FRAME ѲǽʥեȤΥꥹȤ
-    ֤$FONT  NULL ǤʤС$FONT ȹפѲǽʥե
-    ΥꥹȤ֤$LANGUAGE  @c Mnil ǤʤС$LANGUAGE 򥵥ݡ
-    ȤѲǽʥեȤΥꥹȤ֤$MAXNUM ϡ0 礭
-    ˤϡ֤եȤοξ¤Ǥ롣
+    関数 mfont_list () はフレーム $FRAME で利用可能なフォントのリストを
+    返す。$FONT が NULL でなければ、$FONT と合致する利用可能なフォント
+    のリストを返す。$LANGUAGE が @c Mnil でなければ、$LANGUAGE をサポー
+    トする利用可能なフォントのリストを返す。$MAXNUM は、0 より大きい場
+    合には、返すフォントの数の上限である。
 
-     $LANGUAGE ϵǤȤΤˤꡢλѤ
-    ʤեȤ #Mlanguage ץѥƥȤ٤Ǥ롣
-     $FONT ǤˤΥץѥƥäƤ顢 $LANGUAGE ̵
+    ただし、引数 $LANGUAGE は旧版との整合性のためだけにあり、その使用は
+    勧められない。フォントの #Mlanguage プロパティを使うべきである。も
+    し $FONT がすでにこのプロパティを持っていたら、引数 $LANGUAGE は無
 
 
     @return 
-    δؿϥեȥեߥ̾Ǥͤ MFont ֥Ȥؤ
-    ݥ󥿤Ǥ褦plist ֤plist  m17n_object_unref () 
-    ɬפ롣եȤĤʤNULL ֤  */
+    この関数はキーがフォントファミリ名であり値が MFont オブジェクトへの
+    ポインタであるようなplist を返す。plist は m17n_object_unref () で
+    解放する必要がある。フォントが見つからなければNULL を返す。  */
 
 MPlist *
 mfont_list (MFrame *frame, MFont *font, MSymbol language, int maxnum)
@@ -3193,14 +3193,14 @@ mfont_close (MFont *font)
     @return
     This function returns $FONT.  */
 /***ja
-    @brief եȤפ.
+    @brief フォントをダンプする.
 
-    ؿ mdebug_dump_font () ϥե $FONT ɸ२顼Ϥ⤷
-    Ķѿ MDEBUG_DUMP_FONT ǻꤵ줿ե˿ʹ֤˲ɤʷǽ
-    Ϥ롣
+    関数 mdebug_dump_font () はフォント $FONT を標準エラー出力もしくは
+    環境変数 MDEBUG_DUMP_FONT で指定されたファイルに人間に可読な形で出
+    力する。
 
     @return
-    δؿ $FONT ֤  */
+    この関数は $FONT を返す。  */
 
 MFont *
 mdebug_dump_font (MFont *font)
@@ -3234,6 +3234,6 @@ mdebug_dump_font (MFont *font)
 
 /*
   Local Variables:
-  coding: euc-japan
+  coding: utf-8
   End:
 */
