@@ -18,14 +18,14 @@
    You should have received a copy of the GNU Lesser General Public
    License along with the m17n library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   02111-1307, USA.  */
+   Boston, MA 02110-1301 USA.  */
 
 #ifndef _M17N_SYMBOL_H_
 #define _M17N_SYMBOL_H_
 
 #include "plist.h"
 
-struct MSymbolStruct
+struct MSymbol
 {
   /** 1 iff a value of property (including text-property) whose key is
       the symbol is a managed object.  */
